<?php

namespace Renysh\Turismo\Http\Controllers;

use App\Http\Controllers\PublicWebController as PublicController;
use Renysh\Turismo\Interfaces\CatalogoRepositoryInterface;

class CatalogoPublicWebController extends PublicController
{
    /**
     * Constructor.
     *
     * @param type \Renysh\Catalogo\Interfaces\CatalogoRepositoryInterface $catalogo
     *
     * @return type
     */
    public function __construct(CatalogoRepositoryInterface $catalogo)
    {
        $this->repository = $catalogo;
        parent::__construct();
    }

    /**
     * Show catalogo's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $catalogos = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        return $this->theme->of('turismo::public.catalogo.index', compact('catalogos'))->render();
    }

    /**
     * Show catalogo.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $catalogo = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('turismo::public.catalogo.show', compact('catalogo'))->render();
    }
}
