<?php

namespace Renysh\Turismo\Providers;

use Illuminate\Support\ServiceProvider;

class TurismoServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'turismo');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'turismo');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('turismo', function ($app) {
            return $this->app->make('Renysh\Turismo\Turismo');
        });

// Bind Catalogo to repository
        $this->app->bind(
            \Renysh\Turismo\Interfaces\CatalogoRepositoryInterface::class,
            \Renysh\Turismo\Repositories\Eloquent\CatalogoRepository::class
        );        // Bind Catalogoitem to repository
        $this->app->bind(
            \Renysh\Turismo\Interfaces\CatalogoitemRepositoryInterface::class,
            \Renysh\Turismo\Repositories\Eloquent\CatalogoitemRepository::class
        );        // Bind Sitioevento to repository
        $this->app->bind(
            \Renysh\Turismo\Interfaces\SitioeventoRepositoryInterface::class,
            \Renysh\Turismo\Repositories\Eloquent\SitioeventoRepository::class
        );        // Bind Ubicacion to repository
        $this->app->bind(
            \Renysh\Turismo\Interfaces\UbicacionRepositoryInterface::class,
            \Renysh\Turismo\Repositories\Eloquent\UbicacionRepository::class
        );        // Bind Horarioatencion to repository
        $this->app->bind(
            \Renysh\Turismo\Interfaces\HorarioatencionRepositoryInterface::class,
            \Renysh\Turismo\Repositories\Eloquent\HorarioatencionRepository::class
        );        // Bind Calificacion to repository
        $this->app->bind(
            \Renysh\Turismo\Interfaces\CalificacionRepositoryInterface::class,
            \Renysh\Turismo\Repositories\Eloquent\CalificacionRepository::class
        );        // Bind Recurso to repository
        $this->app->bind(
            \Renysh\Turismo\Interfaces\RecursoRepositoryInterface::class,
            \Renysh\Turismo\Repositories\Eloquent\RecursoRepository::class
        );        // Bind Itinerario to repository
        $this->app->bind(
            \Renysh\Turismo\Interfaces\ItinerarioRepositoryInterface::class,
            \Renysh\Turismo\Repositories\Eloquent\ItinerarioRepository::class
        );        // Bind Itinerarioitem to repository
        $this->app->bind(
            \Renysh\Turismo\Interfaces\ItinerarioitemRepositoryInterface::class,
            \Renysh\Turismo\Repositories\Eloquent\ItinerarioitemRepository::class
        );        // Bind Ruta to repository
        $this->app->bind(
            \Renysh\Turismo\Interfaces\RutaRepositoryInterface::class,
            \Renysh\Turismo\Repositories\Eloquent\RutaRepository::class
        );        // Bind Rutaitem to repository
        $this->app->bind(
            \Renysh\Turismo\Interfaces\RutaitemRepositoryInterface::class,
            \Renysh\Turismo\Repositories\Eloquent\RutaitemRepository::class
        );

        $this->app->register(\Renysh\Turismo\Providers\AuthServiceProvider::class);
        $this->app->register(\Renysh\Turismo\Providers\EventServiceProvider::class);
        $this->app->register(\Renysh\Turismo\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['turismo'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/turismo.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/turismo')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/turismo')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
